DataTesterConfigBuilder

Struct DataTesterConfigBuilder 

pub struct DataTesterConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DataTesterConfigBuilder<S>

pub fn build(self) -> DataTesterConfig
where S: IsComplete,

Finish building and return the requested object

pub fn base(self, value: DataActorConfig) -> DataTesterConfigBuilder<SetBase<S>>
where S::Base: IsUnset,

Optional (Some / Option setters). Default: <DataActorConfig as Default>::default().

Base data actor configuration.

pub fn maybe_base( self, value: Option<DataActorConfig>, ) -> DataTesterConfigBuilder<SetBase<S>>
where S::Base: IsUnset,

Optional (Some / Option setters). Default: <DataActorConfig as Default>::default().

Base data actor configuration.

pub fn instrument_ids( self, value: Vec<InstrumentId>, ) -> DataTesterConfigBuilder<SetInstrumentIds<S>>
where S::InstrumentIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<InstrumentId> as Default>::default().

Instrument IDs to subscribe to.

pub fn maybe_instrument_ids( self, value: Option<Vec<InstrumentId>>, ) -> DataTesterConfigBuilder<SetInstrumentIds<S>>
where S::InstrumentIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<InstrumentId> as Default>::default().

Instrument IDs to subscribe to.

pub fn client_id( self, value: ClientId, ) -> DataTesterConfigBuilder<SetClientId<S>>
where S::ClientId: IsUnset,

Optional (Some / Option setters). Client ID to use for subscriptions.

pub fn maybe_client_id( self, value: Option<ClientId>, ) -> DataTesterConfigBuilder<SetClientId<S>>
where S::ClientId: IsUnset,

Optional (Some / Option setters). Client ID to use for subscriptions.

pub fn bar_types( self, value: Vec<BarType>, ) -> DataTesterConfigBuilder<SetBarTypes<S>>
where S::BarTypes: IsUnset,

Optional (Some / Option setters). Bar types to subscribe to.

pub fn maybe_bar_types( self, value: Option<Vec<BarType>>, ) -> DataTesterConfigBuilder<SetBarTypes<S>>
where S::BarTypes: IsUnset,

Optional (Some / Option setters). Bar types to subscribe to.

pub fn subscribe_book_deltas( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeBookDeltas<S>>
where S::SubscribeBookDeltas: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to order book deltas.

pub fn maybe_subscribe_book_deltas( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeBookDeltas<S>>
where S::SubscribeBookDeltas: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to order book deltas.

pub fn subscribe_book_depth( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeBookDepth<S>>
where S::SubscribeBookDepth: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to order book depth snapshots.

pub fn maybe_subscribe_book_depth( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeBookDepth<S>>
where S::SubscribeBookDepth: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to order book depth snapshots.

pub fn subscribe_book_at_interval( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeBookAtInterval<S>>
where S::SubscribeBookAtInterval: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to order book at interval.

pub fn maybe_subscribe_book_at_interval( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeBookAtInterval<S>>
where S::SubscribeBookAtInterval: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to order book at interval.

pub fn subscribe_quotes( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeQuotes<S>>
where S::SubscribeQuotes: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to quotes.

pub fn maybe_subscribe_quotes( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeQuotes<S>>
where S::SubscribeQuotes: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to quotes.

pub fn subscribe_trades( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeTrades<S>>
where S::SubscribeTrades: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to trades.

pub fn maybe_subscribe_trades( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeTrades<S>>
where S::SubscribeTrades: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to trades.

pub fn subscribe_mark_prices( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeMarkPrices<S>>
where S::SubscribeMarkPrices: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to mark prices.

pub fn maybe_subscribe_mark_prices( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeMarkPrices<S>>
where S::SubscribeMarkPrices: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to mark prices.

pub fn subscribe_index_prices( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeIndexPrices<S>>
where S::SubscribeIndexPrices: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to index prices.

pub fn maybe_subscribe_index_prices( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeIndexPrices<S>>
where S::SubscribeIndexPrices: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to index prices.

pub fn subscribe_funding_rates( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeFundingRates<S>>
where S::SubscribeFundingRates: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to funding rates.

pub fn maybe_subscribe_funding_rates( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeFundingRates<S>>
where S::SubscribeFundingRates: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to funding rates.

pub fn subscribe_bars( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeBars<S>>
where S::SubscribeBars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to bars.

pub fn maybe_subscribe_bars( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeBars<S>>
where S::SubscribeBars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to bars.

pub fn subscribe_instrument( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeInstrument<S>>
where S::SubscribeInstrument: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to instrument updates.

pub fn maybe_subscribe_instrument( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeInstrument<S>>
where S::SubscribeInstrument: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to instrument updates.

pub fn subscribe_instrument_status( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeInstrumentStatus<S>>
where S::SubscribeInstrumentStatus: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to instrument status.

pub fn maybe_subscribe_instrument_status( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeInstrumentStatus<S>>
where S::SubscribeInstrumentStatus: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to instrument status.

pub fn subscribe_instrument_close( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeInstrumentClose<S>>
where S::SubscribeInstrumentClose: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to instrument close.

pub fn maybe_subscribe_instrument_close( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeInstrumentClose<S>>
where S::SubscribeInstrumentClose: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to instrument close.

pub fn subscribe_option_greeks( self, value: bool, ) -> DataTesterConfigBuilder<SetSubscribeOptionGreeks<S>>
where S::SubscribeOptionGreeks: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to option greeks.

pub fn maybe_subscribe_option_greeks( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetSubscribeOptionGreeks<S>>
where S::SubscribeOptionGreeks: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to option greeks.

pub fn subscribe_params( self, value: Params, ) -> DataTesterConfigBuilder<SetSubscribeParams<S>>
where S::SubscribeParams: IsUnset,

Optional (Some / Option setters). Optional parameters passed to all subscribe calls.

pub fn maybe_subscribe_params( self, value: Option<Params>, ) -> DataTesterConfigBuilder<SetSubscribeParams<S>>
where S::SubscribeParams: IsUnset,

Optional (Some / Option setters). Optional parameters passed to all subscribe calls.

pub fn request_params( self, value: Params, ) -> DataTesterConfigBuilder<SetRequestParams<S>>
where S::RequestParams: IsUnset,

Optional (Some / Option setters). Optional parameters passed to all request calls.

pub fn maybe_request_params( self, value: Option<Params>, ) -> DataTesterConfigBuilder<SetRequestParams<S>>
where S::RequestParams: IsUnset,

Optional (Some / Option setters). Optional parameters passed to all request calls.

pub fn can_unsubscribe( self, value: bool, ) -> DataTesterConfigBuilder<SetCanUnsubscribe<S>>
where S::CanUnsubscribe: IsUnset,

Optional (Some / Option setters). Default: true.

Whether unsubscribe is supported on stop.

pub fn maybe_can_unsubscribe( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetCanUnsubscribe<S>>
where S::CanUnsubscribe: IsUnset,

Optional (Some / Option setters). Default: true.

Whether unsubscribe is supported on stop.

pub fn request_instruments( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestInstruments<S>>
where S::RequestInstruments: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request instruments on start.

pub fn maybe_request_instruments( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestInstruments<S>>
where S::RequestInstruments: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request instruments on start.

pub fn request_quotes( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestQuotes<S>>
where S::RequestQuotes: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical quotes (not yet implemented).

pub fn maybe_request_quotes( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestQuotes<S>>
where S::RequestQuotes: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical quotes (not yet implemented).

pub fn request_trades( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestTrades<S>>
where S::RequestTrades: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical trades (not yet implemented).

pub fn maybe_request_trades( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestTrades<S>>
where S::RequestTrades: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical trades (not yet implemented).

pub fn request_bars( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestBars<S>>
where S::RequestBars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical bars.

pub fn maybe_request_bars( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestBars<S>>
where S::RequestBars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical bars.

pub fn request_book_snapshot( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestBookSnapshot<S>>
where S::RequestBookSnapshot: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request order book snapshots.

pub fn maybe_request_book_snapshot( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestBookSnapshot<S>>
where S::RequestBookSnapshot: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request order book snapshots.

pub fn request_book_deltas( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestBookDeltas<S>>
where S::RequestBookDeltas: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical order book deltas (not yet implemented).

pub fn maybe_request_book_deltas( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestBookDeltas<S>>
where S::RequestBookDeltas: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical order book deltas (not yet implemented).

pub fn request_funding_rates( self, value: bool, ) -> DataTesterConfigBuilder<SetRequestFundingRates<S>>
where S::RequestFundingRates: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical funding rates.

pub fn maybe_request_funding_rates( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetRequestFundingRates<S>>
where S::RequestFundingRates: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to request historical funding rates.

pub fn book_type( self, value: BookType, ) -> DataTesterConfigBuilder<SetBookType<S>>
where S::BookType: IsUnset,

Optional (Some / Option setters). Default: BookType::L2_MBP.

Book type for order book subscriptions.

pub fn maybe_book_type( self, value: Option<BookType>, ) -> DataTesterConfigBuilder<SetBookType<S>>
where S::BookType: IsUnset,

Optional (Some / Option setters). Default: BookType::L2_MBP.

Book type for order book subscriptions.

pub fn book_depth( self, value: NonZeroUsize, ) -> DataTesterConfigBuilder<SetBookDepth<S>>
where S::BookDepth: IsUnset,

Optional (Some / Option setters). Order book depth for subscriptions.

pub fn maybe_book_depth( self, value: Option<NonZeroUsize>, ) -> DataTesterConfigBuilder<SetBookDepth<S>>
where S::BookDepth: IsUnset,

Optional (Some / Option setters). Order book depth for subscriptions.

pub fn book_interval_ms( self, value: NonZeroUsize, ) -> DataTesterConfigBuilder<SetBookIntervalMs<S>>
where S::BookIntervalMs: IsUnset,

Optional (Some / Option setters). Default: NonZeroUsize::new(1000).unwrap().

Order book interval in milliseconds for at_interval subscriptions.

pub fn maybe_book_interval_ms( self, value: Option<NonZeroUsize>, ) -> DataTesterConfigBuilder<SetBookIntervalMs<S>>
where S::BookIntervalMs: IsUnset,

Optional (Some / Option setters). Default: NonZeroUsize::new(1000).unwrap().

Order book interval in milliseconds for at_interval subscriptions.

pub fn book_levels_to_print( self, value: usize, ) -> DataTesterConfigBuilder<SetBookLevelsToPrint<S>>
where S::BookLevelsToPrint: IsUnset,

Optional (Some / Option setters). Default: 10.

Number of order book levels to print when logging.

pub fn maybe_book_levels_to_print( self, value: Option<usize>, ) -> DataTesterConfigBuilder<SetBookLevelsToPrint<S>>
where S::BookLevelsToPrint: IsUnset,

Optional (Some / Option setters). Default: 10.

Number of order book levels to print when logging.

pub fn manage_book( self, value: bool, ) -> DataTesterConfigBuilder<SetManageBook<S>>
where S::ManageBook: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to manage local order book from deltas.

pub fn maybe_manage_book( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetManageBook<S>>
where S::ManageBook: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to manage local order book from deltas.

pub fn log_data(self, value: bool) -> DataTesterConfigBuilder<SetLogData<S>>
where S::LogData: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to log received data.

pub fn maybe_log_data( self, value: Option<bool>, ) -> DataTesterConfigBuilder<SetLogData<S>>
where S::LogData: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to log received data.

pub fn stats_interval_secs( self, value: u64, ) -> DataTesterConfigBuilder<SetStatsIntervalSecs<S>>
where S::StatsIntervalSecs: IsUnset,

Optional (Some / Option setters). Default: 5.

Stats logging interval in seconds (0 to disable).

pub fn maybe_stats_interval_secs( self, value: Option<u64>, ) -> DataTesterConfigBuilder<SetStatsIntervalSecs<S>>
where S::StatsIntervalSecs: IsUnset,

Optional (Some / Option setters). Default: 5.

Stats logging interval in seconds (0 to disable).