Collection utilities for the data events a client emits onto the live runner channel.
Functions
- collect_
data_ events_ until_ response - Collects the data events received on
rxup to and including the response correlated withrequest_id, then drains any further events available without waiting. - drain_
data_ events - Collects the data events received on
rxwithintimeout.